<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Òtimisacioun e coumpressioun',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Script',
	'item_compresseur_closure' => 'Utilisà Google Closure Compiler [expérimental]',
	'item_compresseur_css' => 'Ativà la coumpressioun dei fuèi de stil (CSS)',
	'item_compresseur_js' => 'Ativà la coumpressioun dei script (javascript)',

	// T
	'texte_compacter_avertissement' => 'Mèfi da noun ativà aqueli oupcioun dau tems dóu desfouloupamen dóu vouòstre sit : lu elemen serat perdon touta legibilità.',
	'texte_compacter_script_css' => 'SPIP pòu serà lu script javascript e li fuèi de stil CSS, per li registrà en de fichié estàticou ; acò achelerà l’afichage dóu sit.',
	'titre_compacter_script_css' => 'Coumpressioun dei script e CSS'
);

?>
